@@ -1,5 +1,5 @@
 /* David Leonard, 2002. Public domain. */
-/* $Id: flow.h 494 2003-08-25 11:10:20Z d $ */
+/* $Id: flow.h 1180 2007-01-18 22:08:04Z d $ */
 
 #include <sys/time.h>
 
@@ -10,10 +10,10 @@ struct flow {
 	char		tag[TAGLEN];
 	char		desc[DESCLEN];
 	unsigned int	taghash;
-	unsigned long	octets;
-	unsigned long	total_octets;
-	unsigned long	packets;
-	unsigned long	total_packets;
+	uint64_t	octets;
+	uint64_t	total_octets;
+	uint64_t	packets;
+	uint64_t	total_packets;
 	double		keepalive;
 	int		dontdel;
 	unsigned long	seq[2];		/* seq no for TCP */
