@@ -1,5 +1,5 @@
 /* David Leonard, 2002. Public domain. */
-/* $Id: ip.c 1172 2006-11-11 13:32:14Z d $ */
+/* $Id: ip.c 1190 2007-08-30 09:23:09Z d $ */
 
 /* Internet protocol version 4 */
 
@@ -202,12 +202,12 @@ ip_pkt_tag(p, end)
 	const struct ip *ip = (const struct ip *)p;
 	const char *pktend;
 	static char tag[TAGLEN];
-	int hlen;
+	unsigned int hlen;
 
 	pktend = p + ntohs(ip->ip_len);
 	if (end < pktend)
 		pktend = end;
-	hlen = ip->ip_hl << 2;
+	hlen = (ip->ip_hl << 2) & 0x3c;
 
 	switch(ip->ip_p) {
 	case IPPROTO_TCP:
