@@ -1,5 +1,5 @@
 /* David Leonard, 2002. Public domain. */
-/* $Id: loop.c 978 2006-01-27 15:01:08Z d $ */
+/* $Id: loop.c 1172 2006-11-11 13:32:14Z d $ */
 
 #if HAVE_CONFIG_H
 # include "config.h"
@@ -15,6 +15,9 @@
 #if HAVE_SYS_SOCKET_H
 # include <sys/socket.h>
 #endif
+#if HAVE_ARPA_INET_H
+# include <arpa/inet.h>
+#endif
 
 #include "compat.h"
 #include "tag.h"
@@ -39,8 +42,10 @@ loop_tag(p, end)
 	switch (ntohl(af)) {
 	case AF_INET:
 		return ip_tag(p, end);
+#if HAVE_NETINET_IP6_H
 	case AF_INET6:
 		return ip6_tag(p, end);
+#endif
 	default:
 		snprintf(tag, sizeof tag, "loop af 0x%04x", af);
 		return tag;
